==> haskell-dependent-sum-0.7.2.0-112-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-F0ZO2eGLI8ND0Ok6E56REp
key:                  dependent-sum-0.7.2.0-F0ZO2eGLI8ND0Ok6E56REp
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  2b8ff5971a26deed5256bb894cda6ca6
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.5-36xIADGNqiWGv9lC459cQD:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.5-36xIADGNqiWGv9lC459cQD:Data.GADT.Show,
    Data.Some from some-1.0.5-36xIADGNqiWGv9lC459cQD:Data.Some

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-F0ZO2eGLI8ND0Ok6E56REp
depends:
    base-4.17.2.1 constraints-extras-0.4.0.1-K4SpbvvC4BaCqOA5oA01AR
    some-1.0.5-36xIADGNqiWGv9lC459cQD

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-0.7.2.0-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-9VFsSMoepXN6fHLQm865SE
key:                  dependent-sum-0.7.2.0-9VFsSMoepXN6fHLQm865SE
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  c57486b9e258c67ad15494bfd6e05f05
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.5-36xIADGNqiWGv9lC459cQD:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.5-36xIADGNqiWGv9lC459cQD:Data.GADT.Show,
    Data.Some from some-1.0.5-36xIADGNqiWGv9lC459cQD:Data.Some

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-9VFsSMoepXN6fHLQm865SE
depends:
    base-4.17.2.1 constraints-extras-0.4.0.1-CzqSA3PNGaBAkPsK1I3nlC
    some-1.0.5-36xIADGNqiWGv9lC459cQD

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
